/****************************************************************************
  ** Utils - class
  **
  **   Created : 
  **        by : Varol Okan using kate editor
  ** Copyright : (c) Varol Okan
  ** License   : GPL v 2.0
  **
  **
  ****************************************************************************/

#ifndef UTILS_H
#define UTILS_H

#include <QString>

class QImage;

class Utils
{
public:
   Utils ( );
  ~Utils ( );


  void frameImage    ( QImage &, int, int, QImage *, unsigned int * );
  void prescaleImage ( QImage &, int );
  void writeZoneCode ( unsigned char, QString );
  bool recMkdir      ( const    QString & );
  unsigned long long SDBMHash ( QString & );
};

#endif // UTILS_H
